==> huaweicloudsdkcdn-3.0.49-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/show_domain_item_location_details_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ShowDomainItemLocationDetailsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'domains': 'list[DomainItemLocationDetails]'
    }

    attribute_map = {
        'domains': 'domains'
    }

    def __init__(self, domains=None):
        """ShowDomainItemLocationDetailsResponse - a model defined in huaweicloud sdk"""
        
        super(ShowDomainItemLocationDetailsResponse, self).__init__()

        self._domains = None
        self.discriminator = None

        if domains is not None:
            self.domains = domains

    @property
    def domains(self):
        """Gets the domains of this ShowDomainItemLocationDetailsResponse.

        域名详情数据列表

        :return: The domains of this ShowDomainItemLocationDetailsResponse.
        :rtype: list[DomainItemLocationDetails]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        """Sets the domains of this ShowDomainItemLocationDetailsResponse.

        域名详情数据列表

        :param domains: The domains of this ShowDomainItemLocationDetailsResponse.
        :type: list[DomainItemLocationDetails]
        """
        self._domains = domains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDomainItemLocationDetailsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdn-3.0.52-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/show_domain_item_location_details_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ShowDomainItemLocationDetailsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'domains': 'list[DomainItemLocationDetails]'
    }

    attribute_map = {
        'domains': 'domains'
    }

    def __init__(self, domains=None):
        """ShowDomainItemLocationDetailsResponse - a model defined in huaweicloud sdk"""
        
        super(ShowDomainItemLocationDetailsResponse, self).__init__()

        self._domains = None
        self.discriminator = None

        if domains is not None:
            self.domains = domains

    @property
    def domains(self):
        """Gets the domains of this ShowDomainItemLocationDetailsResponse.

        域名详情数据列表

        :return: The domains of this ShowDomainItemLocationDetailsResponse.
        :rtype: list[DomainItemLocationDetails]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        """Sets the domains of this ShowDomainItemLocationDetailsResponse.

        域名详情数据列表

        :param domains: The domains of this ShowDomainItemLocationDetailsResponse.
        :type: list[DomainItemLocationDetails]
        """
        self._domains = domains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDomainItemLocationDetailsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
